package com.ruoyi.branch.service;

import java.util.List;
import com.ruoyi.branch.domain.TBranchTemplate;

/**
 * 常用模板Service接口
 * 
 * @author ruoyi
 * @date 2023-08-21
 */
public interface ITBranchTemplateService 
{
    /**
     * 查询常用模板
     * 
     * @param templateId 常用模板主键
     * @return 常用模板
     */
    public TBranchTemplate selectTBranchTemplateByTemplateId(Long templateId);

    /**
     * 查询常用模板列表
     * 
     * @param tBranchTemplate 常用模板
     * @return 常用模板集合
     */
    public List<TBranchTemplate> selectTBranchTemplateList(TBranchTemplate tBranchTemplate);

    /**
     * 新增常用模板
     * 
     * @param tBranchTemplate 常用模板
     * @return 结果
     */
    public int insertTBranchTemplate(TBranchTemplate tBranchTemplate);

    /**
     * 修改常用模板
     * 
     * @param tBranchTemplate 常用模板
     * @return 结果
     */
    public int updateTBranchTemplate(TBranchTemplate tBranchTemplate);

    /**
     * 批量删除常用模板
     * 
     * @param templateIds 需要删除的常用模板主键集合
     * @return 结果
     */
    public int deleteTBranchTemplateByTemplateIds(Long[] templateIds);

    /**
     * 删除常用模板信息
     * 
     * @param templateId 常用模板主键
     * @return 结果
     */
    public int deleteTBranchTemplateByTemplateId(Long templateId);
}
